"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ElasticsearchCatNodes = void 0;
var _error = require("@webiny/error");
var _stripConnectionFromException = require("./stripConnectionFromException");
class ElasticsearchCatNodes {
  constructor(client) {
    this.client = client;
  }
  async getNodes() {
    try {
      const response = await this.client.cat.nodes({
        format: "json"
      });
      if (!Array.isArray(response.body) || response.body.length === 0) {
        throw new _error.WebinyError({
          message: `There is no valid response from cat.nodes operation.`,
          code: "ELASTICSEARCH_NODES_INVALID_RESPONSE",
          data: response.body
        });
      }
      return response.body;
    } catch (ex) {
      console.error(`Could not fetch cluster nodes information: ${ex.message}`);
      const error = (0, _stripConnectionFromException.stripConnectionFromException)(ex);
      console.log(JSON.stringify(error));
      throw error;
    }
  }
}
exports.ElasticsearchCatNodes = ElasticsearchCatNodes;

//# sourceMappingURL=ElasticsearchCatNodes.js.map