"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createIndex = void 0;
var _indices = require("../indices");
var _error = _interopRequireDefault(require("@webiny/error"));
const indexExists = async params => {
  const {
    client,
    index,
    onExists
  } = params;
  try {
    const response = await client.indices.exists({
      index,
      ignore_unavailable: false,
      allow_no_indices: true,
      include_defaults: true,
      flat_settings: false,
      local: false
    });
    if (!response.body) {
      return false;
    }
    if (onExists) {
      onExists();
    }
    return true;
  } catch (ex) {
    console.error(`Could not determine if the index "${index}" exists.`);
  }
  return false;
};
const indexCreate = async params => {
  const {
    client,
    index,
    plugin,
    tenant,
    locale,
    type,
    onError
  } = params;
  try {
    await client.indices.create({
      index,
      body: {
        ...plugin.body
      }
    });
  } catch (ex) {
    let error = ex;
    if (onError) {
      error = onError(ex);
    }
    throw new _error.default(error.message || `Could not create Elasticsearch index for the ${type}.`, error.code || "CREATE_ELASTICSEARCH_INDEX_ERROR", {
      error: {
        ...error,
        message: error.message,
        code: error.code,
        data: error.data
      },
      type,
      locale,
      tenant,
      index,
      body: plugin.body
    });
  }
};
const createIndex = async params => {
  const {
    plugins,
    type,
    locale,
    onExists
  } = params;
  const plugin = (0, _indices.getLastAddedIndexPlugin)({
    container: plugins,
    type,
    locale
  });
  const exists = await indexExists(params);
  if (exists) {
    if (onExists) {
      onExists();
    }
    return;
  }
  await indexCreate({
    ...params,
    plugin
  });
};
exports.createIndex = createIndex;

//# sourceMappingURL=createIndex.js.map